@@ -1,9 +1,9 @@
 package ExtUtils::Builder::Linker::Mach::GCC;
-$ExtUtils::Builder::Linker::Mach::GCC::VERSION = '0.014';
+$ExtUtils::Builder::Linker::Mach::GCC::VERSION = '0.015';
 use strict;
 use warnings;
 
-use base 'ExtUtils::Builder::Linker::Unixy';
+use parent 'ExtUtils::Builder::Linker::Unixy';
 
 sub _init {
 	my ($self, %args) = @_;
@@ -45,7 +45,7 @@ ExtUtils::Builder::Linker::Mach::GCC
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 AUTHOR
 
