@@ -1,11 +1,11 @@
 package ExtUtils::Builder::Linker::PE::MSVC;
-$ExtUtils::Builder::Linker::PE::MSVC::VERSION = '0.014';
+$ExtUtils::Builder::Linker::PE::MSVC::VERSION = '0.015';
 use strict;
 use warnings;
 
 use ExtUtils::Builder::Action::Command;
 
-use base qw/ExtUtils::Builder::Linker::COFF/;
+use parent qw/ExtUtils::Builder::Linker::COFF/;
 
 sub _init {
 	my ($self, %args) = @_;
@@ -28,11 +28,10 @@ sub linker_flags {
 }
 
 sub post_action {
-	# XXX Conditional command?
 	my ($self, $from, $to, %opts) = @_;
 	my @ret = $self->SUPER::post_action(%opts);
 	my $manifest = $opts{manifest} || "$to.manifest";
-	push @ret, ExtUtils::Builder::Action::Command->new(command => [ 'if', 'exist', $manifest, 'mt', '-nologo', $manifest, "-outputresource:$to;2" ]);
+	push @ret, ExtUtils::Builder::Action::Command->new(command => [ 'if', 'exist', $manifest, 'mt', '-nologo', '-manifest', $manifest, "-outputresource:$to;2" ]);
 	return @ret;
 }
 
@@ -50,7 +49,7 @@ ExtUtils::Builder::Linker::PE::MSVC
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 AUTHOR
 
